# -*- coding: utf-8 -*-
# Generated by Django 1.9.3 on 2016-08-02 11:19
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('screenshot', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='screenshot',
            name='height',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='screenshot',
            name='width',
            field=models.IntegerField(blank=True, null=True),
        ),
    ]
