# -*- coding: utf-8 -*-
# Generated by Django 1.9.3 on 2016-04-14 14:35
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('review', '0003_auto_20160413_0517'),
    ]

    operations = [
        migrations.AlterField(
            model_name='review',
            name='cons',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='review',
            name='pros',
            field=models.TextField(blank=True, null=True),
        ),
    ]
