# -*- coding: utf-8 -*-
# Generated by Django 1.9.3 on 2016-04-27 09:59
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('review', '0006_auto_20160425_1011'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='review',
            options={'verbose_name': 'Отзыв', 'verbose_name_plural': 'Отзывы'},
        ),
        migrations.AlterUniqueTogether(
            name='review',
            unique_together=set([('target_content_type', 'target_id', 'author')]),
        ),
    ]
