# -*- coding: utf-8 -*-
# Generated by Django 1.9.3 on 2016-04-27 14:22
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('qna', '0005_auto_20160426_0908'),
    ]

    operations = [
        migrations.AddField(
            model_name='answer',
            name='accepted',
            field=models.BooleanField(default=False),
        ),
    ]
