# -*- coding: utf-8 -*-
# Generated by Django 1.9.3 on 2016-04-30 15:21
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('qna', '0008_auto_20160430_1304'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='question',
            options={'ordering': ['created_at'], 'verbose_name': 'Вопрос', 'verbose_name_plural': 'Вопросы'},
        ),
    ]
