# -*- coding: utf-8 -*-
# Generated by Django 1.9.3 on 2016-04-24 08:27
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('review', '0004_auto_20160414_1435'),
    ]

    operations = [
        migrations.AddField(
            model_name='review',
            name='last_update',
            field=models.DateField(auto_now=True, null=True),
        ),
    ]
