# -*- coding: utf-8 -*-
# Generated by Django 1.9.3 on 2016-08-03 12:43
from __future__ import unicode_literals

from django.db import migrations
import sorl.thumbnail.fields


class Migration(migrations.Migration):

    dependencies = [
        ('screenshot', '0002_auto_20160802_1119'),
    ]

    operations = [
        migrations.AlterField(
            model_name='screenshot',
            name='src',
            field=sorl.thumbnail.fields.ImageField(height_field='height', upload_to='screenshots/', width_field='width'),
        ),
    ]
